@@ -2,6 +2,8 @@
 #![deny(rustdoc::all)]
 #![allow(rustdoc::missing_doc_code_examples)]
 #![deny(missing_docs)]
+#![deny(clippy::unwrap_used)]
+#![deny(clippy::integer_arithmetic)]
 
 pub mod bn;
 pub mod curve;
